==> ejc-zhengyuan-impl-3.0.0-20241227.024427-13-sources.jar: com/ejianc/business/sq/keyan/bean/KeyanInnovationHonorRecognitionEntity.java <==
package com.ejianc.business.sq.keyan.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 创新荣誉认定
 * 
 * @author generator
 * 
 */
 @TableName("ejc_keyan_innovation_honor_recognition")
public class KeyanInnovationHonorRecognitionEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据审批状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="unit_id")
    private Long unitId; // 所属单位id
    @TableField(value="unit_name")
    private String unitName; // 所属单位名称
    @TableField(value="honorary_name")
    private String honoraryName; // 荣誉称号
    @TableField(value="proof_document_type")
    private String proofDocumentType; // 证明文件类型
    @TableField(value="certificate_no")
    private String certificateNo; // 证书编号
    @TableField(value="issue_unit")
    private String issueUnit; // 发证单位
    @TableField(value="issue_date")
    private Date issueDate; // 发证日期
    @TableField(value="period_validity")
    private String periodValidity; // 有效期
    @TableField(value="remarks")
    private String remarks; // 备注

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getHonoraryName() {
        return honoraryName;
    }

    public void setHonoraryName(String honoraryName) {
        this.honoraryName = honoraryName;
    }
    public String getProofDocumentType() {
        return proofDocumentType;
    }

    public void setProofDocumentType(String proofDocumentType) {
        this.proofDocumentType = proofDocumentType;
    }
    public String getCertificateNo() {
        return certificateNo;
    }

    public void setCertificateNo(String certificateNo) {
        this.certificateNo = certificateNo;
    }
    public String getIssueUnit() {
        return issueUnit;
    }

    public void setIssueUnit(String issueUnit) {
        this.issueUnit = issueUnit;
    }
    public Date getIssueDate() {
        return issueDate;
    }

    public void setIssueDate(Date issueDate) {
        this.issueDate = issueDate;
    }
    public String getPeriodValidity() {
        return periodValidity;
    }

    public void setPeriodValidity(String periodValidity) {
        this.periodValidity = periodValidity;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-zhengyuan-impl-3.0.0-20251202.033713-51-sources.jar: com/ejianc/business/sq/keyan/bean/KeyanInnovationHonorRecognitionEntity.java <==
package com.ejianc.business.sq.keyan.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.Date;

/**
 * 创新荣誉认定
 * 
 * @author generator
 * 
 */
 @TableName("ejc_keyan_innovation_honor_recognition")
public class KeyanInnovationHonorRecognitionEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_state")
    private Integer billState; // 单据审批状态
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="unit_id")
    private Long unitId; // 所属单位id
    @TableField(value="unit_name")
    private String unitName; // 所属单位名称
    @TableField(value="honorary_name")
    private String honoraryName; // 荣誉称号
    @TableField(value="proof_document_type")
    private String proofDocumentType; // 证明文件类型
    @TableField(value="certificate_no")
    private String certificateNo; // 证书编号
    @TableField(value="issue_unit")
    private String issueUnit; // 发证单位
    @TableField(value="issue_date")
    private Date issueDate; // 发证日期
    @TableField(value="period_validity")
    private Date periodValidity; // 有效期
    @TableField(value="remarks")
    private String remarks; // 备注

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public String getHonoraryName() {
        return honoraryName;
    }

    public void setHonoraryName(String honoraryName) {
        this.honoraryName = honoraryName;
    }
    public String getProofDocumentType() {
        return proofDocumentType;
    }

    public void setProofDocumentType(String proofDocumentType) {
        this.proofDocumentType = proofDocumentType;
    }
    public String getCertificateNo() {
        return certificateNo;
    }

    public void setCertificateNo(String certificateNo) {
        this.certificateNo = certificateNo;
    }
    public String getIssueUnit() {
        return issueUnit;
    }

    public void setIssueUnit(String issueUnit) {
        this.issueUnit = issueUnit;
    }
    public Date getIssueDate() {
        return issueDate;
    }

    public void setIssueDate(Date issueDate) {
        this.issueDate = issueDate;
    }
    public Date getPeriodValidity() {
        return periodValidity;
    }

    public void setPeriodValidity(Date periodValidity) {
        this.periodValidity = periodValidity;
    }
    public String getRemarks() {
        return remarks;
    }

    public void setRemarks(String remarks) {
        this.remarks = remarks;
    }
    
}
